# Lisa

A simple Python package providing colormaps inspired by the colours of famous artists.

Based on the [Color Lisa](https://colorlisa.com/) project.

### Installation
Install the package from PyPI:
```bash
pip install cm_lisa
```

Or to develop it, clone this repository and install locally:
```bash
pip install -e .
```

### Usage
Simply import the package to make the colormaps available for use with Matplotlib:
```python
import lisa
```
### Demonstration
![Image demonstrating the Lisa colormaps](docs/assets/lisa.svg)

-----------------------------
Available under the GNU General Public License v3.

Copyright (C) 2025 Harrison Nicholls
